spannertools.destroy_all_spanners_attached_to_component
=======================================================

.. autofunction:: abjad.tools.spannertools.destroy_all_spanners_attached_to_component.destroy_all_spanners_attached_to_component
